@@ -18,7 +18,7 @@ pub struct ZigConfig<'a> {
     pub detect_folders: Vec<&'a str>,
 }
 
-impl<'a> Default for ZigConfig<'a> {
+impl Default for ZigConfig<'_> {
     fn default() -> Self {
         ZigConfig {
             format: "via [$symbol($version )]($style)",
